@@ -172,6 +172,38 @@ pub fn build_sql<'a>(sql_id : &'a str, sub_sql_id: &'a str, arg : &HashMap<Strin
 
     bind_variables(sql.as_str(), arg)
 }
+
+pub fn get_static_sql<'a>(sql_id : &'a str, sub_sql_id: &'a str) -> String {
+    let mut sql = String::new();
+    if sub_sql_id.is_empty() {
+
+        sql = String::from(match SQL_CACHE.get(sql_id) {
+
+            Some(f) => f,
+            _ => panic!("No such SQL: {}", sql_id)
+        })
+
+    } else {
+
+        let sub_sql_id = format!("{}.{}", sql_id, sub_sql_id);
+
+        sql = match (SQL_CACHE.get(sql_id),  SQL_CACHE.get(&sub_sql_id)) {
+            (Some(m), Some(n)) => {
+
+                format!("{}\n{}", m, n)
+            }
+            _ => panic!("No such SQL: {}.{}", sql_id, sub_sql_id)
+        }
+    }
+
+    match SQL_CACHE.get(format!("{}.#footer#", sql_id).as_str()) {
+        Some(m) => {
+            sql = format!("{}\n{}", &sql, m);
+        }
+        _ =>{}
+    }
+    sql
+}
 fn is_not_hidden(entry: &walkdir::DirEntry) -> bool {
     entry
         .file_name()
